@@ -31,6 +31,7 @@ import pickle
 import re
 import shutil
 import tarfile
+from contextlib import suppress
 
 import joblib
 import numpy as np
@@ -69,15 +70,16 @@ def _download_20newsgroups(target_dir, cache_path):
     train_path = os.path.join(target_dir, TRAIN_FOLDER)
     test_path = os.path.join(target_dir, TEST_FOLDER)
 
-    if not os.path.exists(target_dir):
-        os.makedirs(target_dir)
+    os.makedirs(target_dir, exist_ok=True)
 
     logger.info("Downloading dataset from %s (14 MB)", ARCHIVE.url)
     archive_path = _fetch_remote(ARCHIVE, dirname=target_dir)
 
     logger.debug("Decompressing %s", archive_path)
     tarfile.open(archive_path, "r:gz").extractall(path=target_dir)
-    os.remove(archive_path)
+
+    with suppress(FileNotFoundError):
+        os.remove(archive_path)
 
     # Store a zipped pickle
     cache = dict(
@@ -153,7 +155,7 @@ def strip_newsgroup_footer(text):
 
 @validate_params(
     {
-        "data_home": [str, None],
+        "data_home": [str, os.PathLike, None],
         "subset": [StrOptions({"train", "test", "all"})],
         "categories": ["array-like", None],
         "shuffle": ["boolean"],
@@ -191,7 +193,7 @@ def fetch_20newsgroups(
 
     Parameters
     ----------
-    data_home : str, default=None
+    data_home : str or path-like, default=None
         Specify a download and cache folder for the datasets. If None,
         all scikit-learn data is stored in '~/scikit_learn_data' subfolders.
 
@@ -351,7 +353,7 @@ def fetch_20newsgroups(
     {
         "subset": [StrOptions({"train", "test", "all"})],
         "remove": [tuple],
-        "data_home": [str, None],
+        "data_home": [str, os.PathLike, None],
         "download_if_missing": ["boolean"],
         "return_X_y": ["boolean"],
         "normalize": ["boolean"],
@@ -411,7 +413,7 @@ def fetch_20newsgroups_vectorized(
         ends of posts that look like signatures, and 'quotes' removes lines
         that appear to be quoting another post.
 
-    data_home : str, default=None
+    data_home : str or path-like, default=None
         Specify an download and cache folder for the datasets. If None,
         all scikit-learn data is stored in '~/scikit_learn_data' subfolders.
 
