@@ -9,7 +9,6 @@ from itertools import cycle, product
 import joblib
 import numpy as np
 import pytest
-from scipy.sparse import csc_matrix, csr_matrix
 
 from sklearn.base import BaseEstimator
 from sklearn.datasets import load_diabetes, load_iris, make_hastie_10_2
@@ -31,6 +30,7 @@ from sklearn.svm import SVC, SVR
 from sklearn.tree import DecisionTreeClassifier, DecisionTreeRegressor
 from sklearn.utils import check_random_state
 from sklearn.utils._testing import assert_array_almost_equal, assert_array_equal
+from sklearn.utils.fixes import CSC_CONTAINERS, CSR_CONTAINERS
 
 rng = check_random_state(0)
 
@@ -83,9 +83,9 @@ def test_classification():
 
 
 @pytest.mark.parametrize(
-    "sparse_format, params, method",
+    "sparse_container, params, method",
     product(
-        [csc_matrix, csr_matrix],
+        CSR_CONTAINERS + CSC_CONTAINERS,
         [
             {
                 "max_samples": 0.5,
@@ -105,7 +105,7 @@ def test_classification():
         ["predict", "predict_proba", "predict_log_proba", "decision_function"],
     ),
 )
-def test_sparse_classification(sparse_format, params, method):
+def test_sparse_classification(sparse_container, params, method):
     # Check classification for various parameter settings on sparse input.
 
     class CustomSVC(SVC):
@@ -121,8 +121,8 @@ def test_sparse_classification(sparse_format, params, method):
         scale(iris.data), iris.target, random_state=rng
     )
 
-    X_train_sparse = sparse_format(X_train)
-    X_test_sparse = sparse_format(X_test)
+    X_train_sparse = sparse_container(X_train)
+    X_test_sparse = sparse_container(X_test)
     # Trained on sparse format
     sparse_classifier = BaggingClassifier(
         estimator=CustomSVC(kernel="linear", decision_function_shape="ovr"),
@@ -174,7 +174,8 @@ def test_regression():
             ).predict(X_test)
 
 
-def test_sparse_regression():
+@pytest.mark.parametrize("sparse_container", CSR_CONTAINERS + CSC_CONTAINERS)
+def test_sparse_regression(sparse_container):
     # Check regression for various parameter settings on sparse input.
     rng = check_random_state(0)
     X_train, X_test, y_train, y_test = train_test_split(
@@ -206,29 +207,28 @@ def test_sparse_regression():
         {"max_samples": 0.5, "bootstrap": True, "bootstrap_features": False},
     ]
 
-    for sparse_format in [csc_matrix, csr_matrix]:
-        X_train_sparse = sparse_format(X_train)
-        X_test_sparse = sparse_format(X_test)
-        for params in parameter_sets:
-            # Trained on sparse format
-            sparse_classifier = BaggingRegressor(
-                estimator=CustomSVR(), random_state=1, **params
-            ).fit(X_train_sparse, y_train)
-            sparse_results = sparse_classifier.predict(X_test_sparse)
+    X_train_sparse = sparse_container(X_train)
+    X_test_sparse = sparse_container(X_test)
+    for params in parameter_sets:
+        # Trained on sparse format
+        sparse_classifier = BaggingRegressor(
+            estimator=CustomSVR(), random_state=1, **params
+        ).fit(X_train_sparse, y_train)
+        sparse_results = sparse_classifier.predict(X_test_sparse)
 
-            # Trained on dense format
-            dense_results = (
-                BaggingRegressor(estimator=CustomSVR(), random_state=1, **params)
-                .fit(X_train, y_train)
-                .predict(X_test)
-            )
+        # Trained on dense format
+        dense_results = (
+            BaggingRegressor(estimator=CustomSVR(), random_state=1, **params)
+            .fit(X_train, y_train)
+            .predict(X_test)
+        )
 
-            sparse_type = type(X_train_sparse)
-            types = [i.data_type_ for i in sparse_classifier.estimators_]
+        sparse_type = type(X_train_sparse)
+        types = [i.data_type_ for i in sparse_classifier.estimators_]
 
-            assert_array_almost_equal(sparse_results, dense_results)
-            assert all([t == sparse_type for t in types])
-            assert_array_almost_equal(sparse_results, dense_results)
+        assert_array_almost_equal(sparse_results, dense_results)
+        assert all([t == sparse_type for t in types])
+        assert_array_almost_equal(sparse_results, dense_results)
 
 
 class DummySizeEstimator(BaseEstimator):
@@ -924,63 +924,6 @@ def test_bagging_get_estimators_indices():
     assert_array_equal(clf.estimators_[0]._sample_indices, clf.estimators_samples_[0])
 
 
-# TODO(1.4): remove in 1.4
-@pytest.mark.parametrize(
-    "Bagging, Estimator",
-    [
-        (BaggingClassifier, DecisionTreeClassifier),
-        (BaggingRegressor, DecisionTreeRegressor),
-    ],
-)
-def test_base_estimator_argument_deprecated(Bagging, Estimator):
-    X = np.array([[1, 2], [3, 4]])
-    y = np.array([1, 0])
-    model = Bagging(base_estimator=Estimator(), n_estimators=10)
-
-    warn_msg = (
-        "`base_estimator` was renamed to `estimator` in version 1.2 and "
-        "will be removed in 1.4."
-    )
-    with pytest.warns(FutureWarning, match=warn_msg):
-        model.fit(X, y)
-
-
-# TODO(1.4): remove in 1.4
-@pytest.mark.parametrize(
-    "Bagging",
-    [BaggingClassifier, BaggingClassifier],
-)
-def test_base_estimator_property_deprecated(Bagging):
-    X = np.array([[1, 2], [3, 4]])
-    y = np.array([1, 0])
-    model = Bagging()
-    model.fit(X, y)
-
-    warn_msg = (
-        "Attribute `base_estimator_` was deprecated in version 1.2 and "
-        "will be removed in 1.4. Use `estimator_` instead."
-    )
-    with pytest.warns(FutureWarning, match=warn_msg):
-        model.base_estimator_
-
-
-# TODO(1.4): remove
-def test_deprecated_base_estimator_has_decision_function():
-    """Check that `BaggingClassifier` delegate to classifier with
-    `decision_function`."""
-    iris = load_iris()
-    X, y = iris.data, iris.target
-    clf = BaggingClassifier(base_estimator=SVC())
-    assert hasattr(clf, "decision_function")
-    warn_msg = (
-        "`base_estimator` was renamed to `estimator` in version 1.2 and "
-        "will be removed in 1.4."
-    )
-    with pytest.warns(FutureWarning, match=warn_msg):
-        y_decision = clf.fit(X, y).decision_function(X)
-    assert y_decision.shape == (150, 3)
-
-
 @pytest.mark.parametrize(
     "bagging, expected_allow_nan",
     [
