@@ -331,8 +331,7 @@ class BaseLibSVM(BaseEstimator, metaclass=ABCMeta):
             y,
             svm_type=solver_type,
             sample_weight=sample_weight,
-            # TODO(1.4): Replace "_class_weight" with "class_weight_"
-            class_weight=getattr(self, "_class_weight", np.empty(0)),
+            class_weight=getattr(self, "class_weight_", np.empty(0)),
             kernel=kernel,
             C=self.C,
             nu=self.nu,
@@ -381,8 +380,7 @@ class BaseLibSVM(BaseEstimator, metaclass=ABCMeta):
             self.coef0,
             self.tol,
             self.C,
-            # TODO(1.4): Replace "_class_weight" with "class_weight_"
-            getattr(self, "_class_weight", np.empty(0)),
+            getattr(self, "class_weight_", np.empty(0)),
             sample_weight,
             self.nu,
             self.cache_size,
@@ -492,8 +490,7 @@ class BaseLibSVM(BaseEstimator, metaclass=ABCMeta):
             self.coef0,
             self.tol,
             C,
-            # TODO(1.4): Replace "_class_weight" with "class_weight_"
-            getattr(self, "_class_weight", np.empty(0)),
+            getattr(self, "class_weight_", np.empty(0)),
             self.nu,
             self.epsilon,
             self.shrinking,
@@ -593,8 +590,7 @@ class BaseLibSVM(BaseEstimator, metaclass=ABCMeta):
             self.coef0,
             self.tol,
             self.C,
-            # TODO(1.4): Replace "_class_weight" with "class_weight_"
-            getattr(self, "_class_weight", np.empty(0)),
+            getattr(self, "class_weight_", np.empty(0)),
             self.nu,
             self.epsilon,
             self.shrinking,
@@ -950,8 +946,7 @@ class BaseSVC(ClassifierMixin, BaseLibSVM, metaclass=ABCMeta):
             self.coef0,
             self.tol,
             self.C,
-            # TODO(1.4): Replace "_class_weight" with "class_weight_"
-            getattr(self, "_class_weight", np.empty(0)),
+            getattr(self, "class_weight_", np.empty(0)),
             self.nu,
             self.epsilon,
             self.shrinking,
@@ -997,14 +992,6 @@ class BaseSVC(ClassifierMixin, BaseLibSVM, metaclass=ABCMeta):
         """
         return self._probB
 
-    # TODO(1.4): Remove
-    @property
-    def _class_weight(self):
-        """Weights per class"""
-        # Class weights are defined for classifiers during
-        # fit.
-        return self.class_weight_
-
 
 def _get_liblinear_solver_type(multi_class, penalty, loss, dual):
     """Find the liblinear magic number for the solver.
